==> minitube-src-0.5.tar.gz: minitube/locale/ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Это жизнь за пределами браузера!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версия %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Эта версия - &quot;технический просмотр&quot;, не стоит ожидать совершенства.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Сообщения об ошибках и идеи следует отправлять на %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 - свободное ПО, но его разработка отнимает драгоценное время.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Поддержите через PayPal&lt;/a&gt; дальнейшую разработку %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Значок создан %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Выпущено на условиях &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Все что Вы всегда хотели узнать о %1 и никогда бы не спросили</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+стрелка назад</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Перейти к предыдущему</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Остановить</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Остановить воспроизведение и вернуться к поиску</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустить</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перейти к следующему видео</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+стрелка вправо</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Приостановить</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Приостановить воспроизведение</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Пробел</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;На весь экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Полноэкранное воспроизведение</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Открыть страницу видео в YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Удалить выбранные видеоклипы из списка воспроизведения</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>В&amp;верх</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Сдвинуть выбранные видеоклипы вверх в списке воспроизведения</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+стрелка вверх</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>В&amp;низ</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Сдвинуть выбранные видеоклипы вниз в списке воспроизведения</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+стрелка вниз</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Пока</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Домашняя страница</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube в интернете</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 в интернете</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Поддержать через PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Поддержите дальнейшую разработку %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Сведения о %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Поиск</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Пр&amp;иложение</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Список воспроизведения</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Видео</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Спр&amp;авка</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Открытие %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Пр&amp;оиграть</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Продолжить воспроизведение</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>В&amp;ыйти из полноэкранного воспроизведения</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Похожие видео</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Недавно просмотренные</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Самые популярные</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Сейчас просматривается &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 просмотров</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Добро пожаловать в &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Введите ключевые слова для начала просмотра видео.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Смотреть</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Последние</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Доступна новая версия %1. &lt;a href=&apos;%2&apos;&gt;Обновите до %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Чувствуйте себя как дома</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
</context>
</TS>

==> minitube-src-0.6.1.tar.gz: minitube/locale/ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Жизнь за пределами браузера!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версия %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Эта предварительная версия, не стоит ожидать совершенства.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Идеи и сообщения об ошибках следует отправлять на %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 - свободное ПО, но его разработка отнимает драгоценное время.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Поддержите через PayPal&lt;/a&gt; дальнейшую разработку %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Автор значка %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Перевод выполнил %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Выпущено на условиях &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Все что Вы всегда хотели узнать о %1 и никогда бы не спросили</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Компактный режим предоставлен %1.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Показать больше %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Видео не найдено</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Больше нет видео</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Alt+стрелка назад</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Перейти к предыдущему</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Остановить</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Остановить воспроизведение и вернуться к поиску</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Esc</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>П&amp;ропустить</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Перейти к следующему видео</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Ctrl+стрелка вправо</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Приостановить</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Приостановить воспроизведение</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Пробел</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;На весь экран</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Полноэкранное воспроизведение</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Alt+Enter</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Открыть страницу видео в YouTube</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Удалить выбранные видеоклипы из списка воспроизведения</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>В&amp;верх</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Сдвинуть выбранные видеоклипы вверх в списке воспроизведения</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Ctrl+стрелка вверх</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>В&amp;низ</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Сдвинуть выбранные видеоклипы вниз в списке воспроизведения</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Ctrl+стрелка вниз</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Пока</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Домашняя страница</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube в интернете</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 в интернете</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Поддержать через PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Поддержите дальнейшую разработку %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Сведения о %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Поиск</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Пр&amp;иложение</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Список воспроизведения</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Видео</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Спр&amp;авка</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Открытие %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Пр&amp;оиграть</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Продолжить воспроизведение</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>В&amp;ыйти из полноэкранного воспроизведения</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Компактный режим</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Скрыть список воспроизведения и панель инструментов</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Фатальная ошибка: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ошибка: %1</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Громкость %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Звук выключен</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Звук включен</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Нажмите %1 для увеличения громкости и %2 для снижения</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Времени осталось: %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Похожие видео</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Недавно просмотренные</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Самые популярные</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Сейчас просматривается &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Ошибка сети: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 просмотров</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Добро пожаловать в &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Введите ключевые слова для начала просмотра видео.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Смотреть</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Последние запросы</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Доступна новая версия %1. &lt;a href=&apos;%2&apos;&gt;Обновите до %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Чувствуйте себя как дома</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation>&amp;Параметры видео</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation>Использовать по возможности видео высокого качества</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation>&amp;Сохранённые последние запросы</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Очистить последние запросы</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Ошибка сети: %1 на %2</translation>
    </message>
</context>
</TS>
